@@ -28,34 +28,44 @@ template< typename T >
 struct scalar_operator_iterator : public std::iterator< std::bidirectional_iterator_tag, T > {
 private:
     T m_value;
+    uint64_t m_count;
 
 public:
     inline scalar_operator_iterator() {}
 
-    inline scalar_operator_iterator(const T &val) : m_value(val) {}
+    inline scalar_operator_iterator(const T &val) : m_value(val), m_count(0) {}
 
+    inline scalar_operator_iterator(const T &val, const uint64_t count)
+        : m_value(val), m_count(count) {}
+        
     inline T operator*() {
        return m_value;
     }
 
     inline scalar_operator_iterator &operator++() {
+        ++m_count;
         return *this;
     }
 
     inline scalar_operator_iterator operator++(int) {
-        return *this;
+        scalar_operator_iterator i = *this;
+        operator++();
+        return i;
     }
 
     inline scalar_operator_iterator &operator--() {
-         return *this;
-    }
-
-    inline scalar_operator_iterator operator--(int) {
+        --m_count;
         return *this;
     }
 
+    inline scalar_operator_iterator operator--(int) {
+        scalar_operator_iterator i = *this;
+        operator--();
+        return i;
+    }
+
     inline bool operator==(const scalar_operator_iterator &rhs) const {
-        return false;
+        return m_count == rhs.m_count;
     }
 
     inline bool operator!=(const scalar_operator_iterator &rhs) const {
@@ -80,14 +90,23 @@ public:
 
 private:
     T m_value;
+    dims_t m_dims;
+    
 public:
-    scalar_operator(const T &val) :
-        m_value(val) {}
+    scalar_operator(const T &val) : m_value(val) {
+        m_dims.first = -1;
+        m_dims.second = 0;
+    }
+    
+    scalar_operator(const T &val, uint64_t maxSize) : m_value(val) {
+        m_dims.first = maxSize;
+        m_dims.second = 0;
+    }
 
-    dims_t dims() const {return std::make_pair(-1, 0);}
-    uint64_t size() const {return -1;}
+    dims_t dims() const {return m_dims;}
+    uint64_t size() const {return m_dims.first;}
     const_iterator begin() const {return const_iterator(m_value);}
-    const_iterator end() const {return const_iterator(m_value);}
+    const_iterator end() const {return const_iterator(m_value, m_dims.first);}
 };
 
 struct make_scalar_operator {
@@ -95,6 +114,11 @@ struct make_scalar_operator {
     scalar_operator< T > operator()(const T &obj) {
         return scalar_operator< T >(obj);
     }
+    
+    template< typename T >
+    scalar_operator< T > operator()(const T &obj, uint64_t count) {
+        return scalar_operator< T >(obj, count);
+    }
 };
 
 } // namespace RcppHoney
